# coding=utf-8
''' Sources avaliable for the kmm module are defined in this module '''

from core.Model import *

class KmmSources:
      ''' Container class for all sources of the driver kmm '''
      
      def __init__(self):
            ''' Default constructor '''
            self.sources = {}        
            self._initSources()
        
      def _initSources(self):
            ''' Initializes the sources defined '''
            self.sources["Yahoo"] = SourceItem("Yahoo",
                  "http://finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d1",
                  "\"([^,\"]*)\",.*",  # symbolregexp
                  "[^,]*,([^,]*),.*", # priceregexp
                  "[^,]*,[^,]*,\"([^\"]*)\"", # dateregexp
                  "%m/%d/%Y" # dateformat
            )

            # sl1d1 format for Yahoo France doesn't seem to give a date ever
            # sl1d3 gives us time (99h99) and date
            self.sources["YahooFrance"] = SourceItem("Yahoo France",
                  "http://fr.finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d3",
                  "([^;]*).*",             # symbolregexp
                  "[^;]*.([^;]*),*",       # priceregexp
                  "[^;]*.[^;]*...h...([^;]*)", # dateregexp
                  "%d/%m/%Y"               # dateformat
            )

            self.sources["VWD.DE"] = SourceItem("VWD.DE",
                  "http://www.finanztreff.de/ftreff/kurse_einzelkurs_uebersicht.htm?s=%1",
                  "",  # symbolregexp
                  "[Kurs|Realtime]: \\d+\\D+\\d+\\D+\\d+ ([0-9.]+,\\d+)", # priceregexp
                  "Jahreschart (\\d+\\D+\\d+\\D+\\d+)", # dateregexp
                  "%d.%m.%Y" # dateformat
            )

            # The following two price sources were contributed by
            # Marc Zahnlecker <tf2k@users.sourceforge.net>
            self.sources["WallstreetOnline"] = SourceItem("Wallstreet-Online.DE (Default)",
                  "http://www.wallstreet-online.de/si/?k=%1&spid=ws",
                  "Symbol:(\\w+)",  # symbolregexp
                  "Portfolio Watchlist ([0-9.]+,\\d+)", # priceregexp
                  ", (\\d+\\D+\\d+\\D+\\d+)", # dateregexp
            "%d.%m.%y" # dateformat
            )

            # (tf2k) The "mpid" is I think the market place id. In this case five
            # stands for Hamburg.
            #
            # Here the id for several market places: 2 Frankfurt, 3 Berlin, 4
            # Düsseldorf, 5 Hamburg, 6 München/Munich, 7 Hannover, 9 Stuttgart, 10
            # Xetra, 32 NASDAQ, 36 NYSE
            self.sources["WallstreetOnlineHamburg"] = SourceItem("Wallstreet-Online.DE (Hamburg)",
                  "http://www.wallstreet-online.de/si/?k=%1&spid=ws&mpid=5",
                  "Symbol:(\\w+)",  # symbolregexp
                  "Portfolio Watchlist ([0-9.]+,\\d+)", # priceregexp
                  # "Letzter Kurs: ([0-9.]+,\\d+)", # priceregexp
                  ", (\\d+\\D+\\d+\\D+\\d+)", # dateregexp
                  "%d.%m.%y" # dateformat
            )        

            # This quote source provided by Danny Scott
            self.sources["YahooCanada"] = SourceItem("Yahoo Canada",
                  "http://ca.finance.yahoo.com/q?s=%1",
                  "%1", # symbol regexp
                  "Net Asset Value: (\\d+\\.\\d+)", # price regexp
                  "day, (.\\D+\\d+\\D+\\d+)", # date regexp
                  "%B %d, %Y" # date format
            )

            ##        self.sources["YahooCurrency"] = SourceItem("Yahoo Currency",
            ##            "http://finance.yahoo.com/d/quotes.csv?s=%1%2=X&f=sl1d1",
            ##            "\"([^,\"]*)\",.*",  # symbolregexp
            ##            "[^,]*,([^,]*),.*", # priceregexp
            ##            "[^,]*,[^,]*,\"([^\"]*)\"", # dateregexp
            ##            "%m/%d/%Y" # dateformat
            ##        )

            ##        self.sources["YahooUK"] = SourceItem("Yahoo UK",
            ##            "http://uk.finance.yahoo.com/d/quotes.csv?s=%1&f=sl1t1",
            ##            "\"([^,\"]*)\",.*",  # symbolregexp
            ##            "[^,]*,([^,]*),.*", # priceregexp
            ##            "[^,]*,[^,]*,\"([^\"]*)\"", # dateregexp
            ##            "%m/%d/%Y" # dateformat
            ##        )

            ##        self.sources["GlobeAndMail"] = SourceItem("Globe & Mail",
            ##            "http://globefunddb.theglobeandmail.com/gishome/plsql/gis.price_history?pi_fund_id=%1",
            ##            "",  # symbolregexp
            ##            "Reinvestment Price \\w+ \\d+, \\d+ (\\d+\\.\\d+)", # priceregexp
            ##            "Reinvestment Price (\\w+ \\d+, \\d+)", # dateregexp
            ##            "%m %d %Y" # dateformat
            ##        )

            ##        self.sources["MSN.CA"] = SourceItem("MSN.CA",
            ##            "http://ca.moneycentral.msn.com/investor/quotes/quotes.asp?symbol=%1",
            ##            "",  # symbolregexp
            ##            "Net Asset Value (\\d+\\.\\d+)", # priceregexp
            ##            "NAV update (\\d+\\D+\\d+\\D+\\d+)", # dateregexp
            ##            "%d %m %y" # dateformat
            ##        )

            ##        # This quote source provided by Peter Lord
            ##        # The trading symbol will normally be the SEDOL (see wikipedia) but
            ##        # the flexibility presently (1/2008) in the code will allow use of
            ##        # the ISIN or MEXID (FT specific) codes
            ##        self.sources["FinancialTimesUKFunds"] = SourceItem("Financial Times UK Funds",
            ##            "http://funds.ft.com/funds/simpleSearch.do?searchArea=%&search=%1",
            ##            "SEDOL[\\ ]*(\\d+.\\d+)", # symbol regexp
            ##            "\\(GBX\\)[\\ ]*([0-9,]*.\\d+)[\\ ]*", # price regexp
            ##            "Valuation date:[\\ ]*(\\d+/\\d+/\\d+)", # date regexp
            ##            "%d/%m/%y" # date format
            ##        )




      def getSourceNames(self):
            ''' Returns a list of names of the sources available '''
            return self.sources.keys()

      def getSourceItem(self, name):
            ''' Returns a SourceItem instance for source with name = <name> provided
            as arguemtn .'''
            if self.sources.has_key(name):
                  return self.sources[name]
            return None
        



